@@ -172,7 +172,7 @@ static int __schema_object_construct(PyGObject *self, PyObject *args, PyObject *
 	
 	midgard_object_set_connection(mobj, mgd);
 
-	MGDOBJECT_DEBUG("__init__");
+	//MGDOBJECT_DEBUG("__init__");
 
 	/* FIXME
 	 * I parse arguments again , but I really do not have idea how to 
